==> aster-full-src-7.4.0-4.tar.gz: STA7.4/bibfor/elements/te0119.f <==
      SUBROUTINE TE0119(OPTION,NOMTE)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 30/03/2004   AUTEUR CIBHHLV L.VIVAN 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
      IMPLICIT NONE
      CHARACTER*16 OPTION,NOMTE
C ----------------------------------------------------------------------
C     BUT: CALCUL DE LA MATRICE DE PASSAGE NOEUDS -> GAUSS
C          POUR LES ELEMENTS ISOPARAMETRIQUES 3D
C ----------------------------------------------------------------------
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------
      INTEGER JGANO,NNO,KP,INO,K,IVF,IRET
      INTEGER NPG,JMANO,IPOIDS,NDIM,JTAB(7),NNOS,IDFDE


      CALL ELREF4(' ','RIGI',NDIM,NNO,NNOS,NPG,IPOIDS,IVF,IDFDE,JGANO)
      CALL TECACH('OON','PMANOPG',7,JTAB,IRET)
      CALL ASSERT(JTAB(6).EQ. (NPG*NNO+2))
      JMANO = JTAB(1)
      ZR(JMANO-1+1) = NNO
      ZR(JMANO-1+2) = NPG

      DO 20 KP = 1,NPG
        K = (KP-1)*NNO
        DO 10 INO = 1,NNO
          ZR(JMANO-1+2+NNO* (KP-1)+INO) = ZR(IVF+K+INO-1)
   10   CONTINUE
   20 CONTINUE

      END

==> aster-full-src-8.1.0-1.tar.gz: STA8.1/bibfor/elements/te0119.f <==
      SUBROUTINE TE0119(OPTION,NOMTE)
C            CONFIGURATION MANAGEMENT OF EDF VERSION
C MODIF ELEMENTS  DATE 25/01/2005   AUTEUR GENIAUT S.GENIAUT 
C ======================================================================
C COPYRIGHT (C) 1991 - 2001  EDF R&D                  WWW.CODE-ASTER.ORG
C THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
C IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
C THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
C (AT YOUR OPTION) ANY LATER VERSION.

C THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
C WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
C MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
C GENERAL PUBLIC LICENSE FOR MORE DETAILS.

C YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
C ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
C    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
C ======================================================================
      IMPLICIT NONE
      CHARACTER*16 OPTION,NOMTE
C ----------------------------------------------------------------------
C     BUT: CALCUL DE LA MATRICE DE PASSAGE NOEUDS -> GAUSS
C          POUR LES ELEMENTS ISOPARAMETRIQUES 3D
C ----------------------------------------------------------------------
C --------- DEBUT DECLARATIONS NORMALISEES  JEVEUX ---------------------
      INTEGER ZI
      COMMON /IVARJE/ZI(1)
      REAL*8 ZR
      COMMON /RVARJE/ZR(1)
      COMPLEX*16 ZC
      COMMON /CVARJE/ZC(1)
      LOGICAL ZL
      COMMON /LVARJE/ZL(1)
      CHARACTER*8 ZK8
      CHARACTER*16 ZK16
      CHARACTER*24 ZK24
      CHARACTER*32 ZK32
      CHARACTER*80 ZK80
      COMMON /KVARJE/ZK8(1),ZK16(1),ZK24(1),ZK32(1),ZK80(1)
C --------- FIN  DECLARATIONS  NORMALISEES  JEVEUX ---------------------
      INTEGER JGANO,NNO,KP,INO,K,IVF,IRET
      INTEGER NPG,JMANO,IPOIDS,NDIM,JTAB(7),NNOS,IDFDE
      CHARACTER*8  ELREFE,ELFD

      CALL ELREF1(ELREFE)

      IF (NOMTE.EQ.'MECA_X_HEXA20')  THEN
        ELFD='H20'
      ELSEIF (NOMTE.EQ.'MECA_X_PENTA15') THEN
        ELFD='P15'
      ELSEIF (NOMTE.EQ.'MECA_X_TETRA10') THEN
        ELFD='T10'
      ELSE
        ELFD=ELREFE
      ENDIF

      CALL ELREF4(ELFD,'RIGI',NDIM,NNO,NNOS,NPG,IPOIDS,IVF,IDFDE,JGANO)
      CALL TECACH('OON','PMANOPG',7,JTAB,IRET)
        
      CALL ASSERT(JTAB(6).EQ. (NPG*NNO+2))
      
      JMANO = JTAB(1)
      ZR(JMANO-1+1) = NNO
      ZR(JMANO-1+2) = NPG

      DO 20 KP = 1,NPG
        K = (KP-1)*NNO
        DO 10 INO = 1,NNO
          ZR(JMANO-1+2+NNO* (KP-1)+INO) = ZR(IVF+K+INO-1)
   10   CONTINUE
   20 CONTINUE

      END
